@@ -5,9 +5,9 @@
 package Data::Dump::Color;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-04'; # DATE
+our $DATE = '2021-06-05'; # DATE
 our $DIST = 'Data-Dump-Color'; # DIST
-our $VERSION = '0.244'; # VERSION
+our $VERSION = '0.245'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -43,7 +43,8 @@ $TRY_BASE64 = 50 unless defined $TRY_BASE64;
 $INDENT = "  " unless defined $INDENT;
 $INDEX = 1 unless defined $INDEX;
 $LENTHRESHOLD = 500 unless defined $LENTHRESHOLD;
-$COLOR = $ENV{COLOR} // (-t STDOUT) // 1;
+$COLOR = (defined $ENV{NO_COLOR} ? 0 : undef) //
+    $ENV{COLOR} // (-t STDOUT) // 1;
 $COLOR_THEME = $ENV{DATA_DUMP_COLOR_THEME} //
     (($ENV{TERM} // "") =~ /256/ ? 'Default256' : 'Default16');
 our $ct_obj;
@@ -512,8 +513,8 @@ sub _dump
             #say "DEBUG: key=<$key>, vpad=<$vpad>, val=<$val>, lenvlastline=<$lenvlastline>, cpad=<$cpad>" if $DEBUG;
             my $visaid = "";
             $visaid .= sprintf("%s{%${idxwidth}i}", "." x @$idx, $i) if $INDEX;
-            $visaid .= " klen=".length($origk) if length($origk) >= $LENTHRESHOLD;
-            $visaid .= " vlen=".length($origv) if length($origv) >= $LENTHRESHOLD;
+            $visaid .= " klen=".length($origk) if defined $origk && length($origk) >= $LENTHRESHOLD;
+            $visaid .= " vlen=".length($origv) if defined $origv && length($origv) >= $LENTHRESHOLD;
 	    $out  .= "$kpad$key => $val," . ($nl && length($visaid) ? " $cpad# $visaid" : "") . $nl;
 	    $cout .= $kpad._col(key=>$key)." => $cval,".($nl && length($visaid) ? " $cpad"._col(comment => "# $visaid") : "") . $nl;
             $i++;
@@ -766,7 +767,7 @@ Data::Dump::Color - Like Data::Dump, but with color
 
 =head1 VERSION
 
-This document describes version 0.244 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-04.
+This document describes version 0.245 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-05.
 
 =head1 SYNOPSIS
 
@@ -842,8 +843,8 @@ Additional variables include:
 =item $COLOR => BOOL (default: undef)
 
 Whether to force-enable or disable color. If unset, color output will be
-determined from C<$ENV{COLOR}> or when in interactive terminal (when C<-t
-STDOUT> is true).
+determined from L</NO_COLOR>, L</COLOR> environment variables, or whether
+running in interactive terminal (when C<-t STDOUT> is true).
 
 =item $COLOR_THEME => str
 
@@ -885,31 +886,27 @@ off, you can set environment COLOR to 0, or C<$Data::Dump::Color::COLOR> to 0.
 
 =head2 How do I customize colors?
 
-Fiddle the colors in C<%Data::Dump::Color::COLORS>. There will probably be
-proper color theme support in the future (based on
-L<SHARYANTO::Role::ColorTheme>.
+Create a color theme and give it a name under
+C<ColorTheme::Data::Dump::Color::*>. See an existing color theme for example,
+e.g. L<ColorTheme::Data::Dump::Color::Default256>.
 
 =head1 ENVIRONMENT
 
-=over
-
-=item * DATA_DUMP_COLOR_THEME
+=head2 DATA_DUMP_COLOR_THEME
 
 Set color theme. Name will be searched under C<ColorTheme::Data::Dump::Color::*>
 or C<ColorTheme::*>.
 
-=item * NO_COLOR
+=head2 NO_COLOR
 
 Can be used to disable color. Takes precedence over the C<COLOR> environment.
 See L<https://no-color.org> for more details.
 
-=item * COLOR
+=head2 COLOR
 
 If set, then will force color output on or off. By default, will only output
 color when in interactive terminal. This is consulted when C<$COLOR> is not set.
 
-=back
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Dump-Color>.
